function  plotSprings(x,k)
%  plotSprings(x,k) 
%  PLOTSPRINGS - plots positions and strength of springs in a semi-nice way
%   
% x - vector of spring positions
% k - vector of spring constants

   subplot(1,2,1); 
   plot(k,[1:length(k)],'b+-');
   xlabel('Spring constant k');
   ylabel('spring number');
   set(gca,'YDir','reverse');
   title(gca,'Spring strength');
   subplot(1,2,2);
   plot(1,0,'rs'); hold on
   plot(1,x,'bs');
   plot([1 1],[0 max(x)],'k--');
   hold off;
   ylabel('Spring Position x');   

   set(gca,'YDir','reverse');
   return
   
   
   
%	$Id: plotSprings.m 1.4 06/01/26 09:03:08-05:00 mspieg@mingus.ldeo.columbia.edu $	
